/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file demo_i2c.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "demo_i2c.h"

/****************************************************************************/
/*	Local pre-processor symbols('#define')
****************************************************************************/
/*----AT24C256ַ+д-----------------------------------------------------*/
#define  AT24C256_WRITE		0xA0				/*Write Cmd*/
#define  AT24C256_READ      0xA1				/*Read  Cmd*/
#define  AT24C256_MAX		0x7fff				/*address  max*/

/*----I2Cģʽ-------------------------------------------------------*/
#define I2C_MASTER_START_SEND				(I2C_I2CMCR_START_Msk | I2C_I2CMCR_RUN_Msk)		/*ʼλ+ӻַ+д+1Byte*/
#define I2C_MASTER_SEND						(I2C_I2CMCR_RUN_Msk)							/*1Byte*/
#define I2C_MASTER_STOP						(I2C_I2CMCR_STOP_Msk)							/*ֹͣλ*/
#define I2C_MASTER_START_RECEIVE_NACK		(I2C_I2CMCR_START_Msk | I2C_I2CMCR_RUN_Msk)		/*ʼλ+ӻַ++1Byteʱ+NACK*/
#define I2C_MASTER_START_RECEIVE_ACK		(I2C_I2CMCR_START_Msk | I2C_I2CMCR_RUN_Msk | I2C_I2CMCR_ACK_Msk) /*ʼλ+ӻַ++1Byteʱ+ACK*/
#define I2C_MASTER_RECEIVE_NACK				(I2C_I2CMCR_RUN_Msk)							/*Ͷ1Byteʱ+NACK*/
#define I2C_MASTER_RECEIVE_ACK				(I2C_I2CMCR_RUN_Msk | I2C_I2CMCR_ACK_Msk)		/*Ͷ1Byteʱ+ACK*/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/
/*****************************************************************************
 ** \brief	I2C_SendMasterCmd
 **			
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void  I2C_SendMasterCmd(uint8_t Cmd)
{
	I2CMCR = Cmd;
}
/*****************************************************************************
 ** \brief	I2C_MasterWriteAddr
 **			дӻַ
 ** \param [in] SlaveAddr ӻַ+дλR/W
 ** \return  none
 ** \note	 дλڴӻַĵ0λ7λַ+R/W  
*****************************************************************************/
void  I2C_MasterWriteAddr(uint8_t SlaveAddr)
{
	I2CMSA   = SlaveAddr;
}
/*****************************************************************************
 ** \brief	I2C_MasterWriteBuffer
 **			д
 ** \param [in] data
 ** \return  none
 ** \note	 
*****************************************************************************/
void  I2C_MasterWriteBuffer(uint8_t Data)
{
	I2CMBUF = Data;
}
/*****************************************************************************
 ** \brief	I2C_MasterReadBuffer
 **			ض
 ** \param [in] none
 ** \return  data
 ** \note	 
*****************************************************************************/
uint8_t I2C_MasterReadBuffer(void)
{
	return I2CMBUF;
}

/*****************************************************************************
 ** \brief	 At24c256_write_byte
 **			 дݵAt24C256
 ** \param [in] addr ַ
**				ch   : 
 **            	
 ** \return  -1ַΧ 0д
 ** \note  
 *****************************************************************************/
int16_t  At24c256_write_byte(uint16_t addr , uint8_t ch)
{
	volatile int16_t i,j;
	if(addr >AT24C256_MAX)
		return -1;
	else
	{			
		
		I2C_MasterWriteAddr(AT24C256_WRITE);			/*дӻַ+д*/
		I2C_MasterWriteBuffer((addr>>8)& 0xff);			/*дBuffer(λROM ַ)*/
		I2C_SendMasterCmd(I2C_MASTER_START_SEND);
		while(!(I2C_GetMasterIntFlag()));				/*ȴͽ*/
		I2C_ClearMasterIntFlag();
								
		I2C_MasterWriteBuffer(addr & 0xff);				/*λROM ַ*/
		I2C_SendMasterCmd(I2C_MASTER_SEND);				/*Buffer*/
		while(!(I2C_GetMasterIntFlag()));
		I2C_ClearMasterIntFlag();	
		
		I2C_MasterWriteBuffer(ch);							/*д*/
		I2C_SendMasterCmd(I2C_MASTER_SEND);
		while(!(I2C_GetMasterIntFlag()));		
		I2C_ClearMasterIntFlag();
		
		I2C_SendMasterCmd(I2C_MASTER_STOP);					/*ֹͣλ*/
		for(i=2000;i>0;i--)								/*ʱȷAT24C256д*/
			for(j=200;j>0;j--);
	}
	return 0;
}

/********************************************************************************
 ** \brief	 At24c256_read_byte
 **			 At24C256ж
 ** \param [in]  addr : ַ
 **            	
 ** \return  8λ
 ** \note   
 ******************************************************************************/
uint8_t  At24c256_read_byte(uint16_t addr)
{
	unsigned char buffer;
	if(addr > AT24C256_MAX)
		return -1;
	
	I2C_MasterWriteAddr(AT24C256_WRITE);			/*дӻַ+д*/
	I2C_MasterWriteBuffer((addr>>8)& 0xff);			/*дBuffer(λROM ַ)*/
	I2C_SendMasterCmd(I2C_MASTER_START_SEND);
	while(!(I2C_GetMasterIntFlag()));				/*ȴͽ*/
	I2C_ClearMasterIntFlag();
							
	I2C_MasterWriteBuffer(addr & 0xff);				/*λROM ַ*/
	I2C_SendMasterCmd(I2C_MASTER_SEND);				/*Buffer*/
	while(!(I2C_GetMasterIntFlag()));
	I2C_ClearMasterIntFlag();	
	
	I2C_MasterWriteAddr(AT24C256_READ);					/*дӻַ+*/	
	I2C_SendMasterCmd(I2C_MASTER_START_RECEIVE_NACK);	
		
	while(!(I2C_GetMasterIntFlag()));					/*ȴݽ*/
	I2C_ClearMasterIntFlag();							
	buffer=I2C_MasterReadBuffer();						/*ȡ*/
	
	I2C_SendMasterCmd(I2C_MASTER_STOP);					/*ֹͣλ*/
	return buffer;
}
/********************************************************************************
 ** \brief	 At24c256_read_str
 **			 ȡAt24c256
 ** \param [in] addr ʼַ
 **            	ch	 : ݱ()  
**				sizevalue: ȡݵĸ
 ** \return  0/1
 ** \note  	   unsigned char  array[10];			//һ10ֽڵ
 **	  At24c256_read_str(0x0010, Buffer, 5); //ӵַ0x0010ʼȡ5ֽڵݷŵarray
 ******************************************************************************/
uint16_t At24c256_read_str(uint16_t addr,  uint8_t *ch, uint16_t sizevalue)
{
	volatile int16_t i;
	if(addr > AT24C256_MAX)
		return 0;
	
	I2C_MasterWriteAddr(AT24C256_WRITE);			/*дӻַ+д*/
	I2C_MasterWriteBuffer((addr>>8)& 0xff);			/*дBuffer(λROM ַ)*/
	I2C_SendMasterCmd(I2C_MASTER_START_SEND);
	while(!(I2C_GetMasterIntFlag()));				/*ȴͽ*/
	I2C_ClearMasterIntFlag();
							
	I2C_MasterWriteBuffer(addr & 0xff);				/*λROM ַ*/
	I2C_SendMasterCmd(I2C_MASTER_SEND);				/*Buffer*/
	while(!(I2C_GetMasterIntFlag()));
	I2C_ClearMasterIntFlag();	
	
	I2C_MasterWriteAddr(AT24C256_READ);					/*дӻַ+*/	
	I2C_SendMasterCmd(I2C_MASTER_START_RECEIVE_ACK);	

	for(i=0;i<sizevalue-2;i++)
	{		
		while(!(I2C_GetMasterIntFlag()));				/*ȴݽ*/
		I2C_ClearMasterIntFlag();						
		*ch++ = I2C_MasterReadBuffer();					/**/
		I2C_SendMasterCmd(I2C_MASTER_RECEIVE_ACK);
	}
	
	while(!(I2C_GetMasterIntFlag()));
	I2C_ClearMasterIntFlag();							
	*ch++ =I2C_MasterReadBuffer();	
	
	while(!(I2C_GetMasterIntFlag()));
	I2C_ClearMasterIntFlag();			
	I2C_SendMasterCmd(I2C_MASTER_RECEIVE_NACK);			/*ȡһ,ACK*/
	*ch =I2C_MasterReadBuffer();														
														
	I2C_SendMasterCmd(I2C_MASTER_STOP);					/*ֹͣλ*/
	return 1;
}
/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
****************************************************************************/
/******************************************************************************
 ** \brief	 I2C_Config
 ** \param [in] 
 **            	
 ** \return  none
 ** \note  
 ******************************************************************************/
void I2C_Config(void)
{
	/*
	 (1)I2Cģʽ
	 */
	 I2C_EnableMasterMode();
	/*
	 (2)I2CͨѶʱ
	 */	 
	I2C_ConfigCLK(15);							/*ʱ100K*/
	/*
	(3)IO
	*/
	 GPIO_SET_MUX_MODE(P04CFG, GPIO_P04_MUX_SCL);			/*SCL*/
	 GPIO_SET_MUX_MODE(P05CFG, GPIO_P05_MUX_SDA);	 		/*SDA*/	 
	 GPIO_SET_PS_MODE(PS_SDA,GPIO_I2C_SDA_SEL_P05);	 
	 GPIO_SET_PS_MODE(PS_SCL,GPIO_I2C_SCL_SEL_P04);	 
}








