/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file demo_led.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "demo_led.h"

/****************************************************************************/
/*	Local pre-processor symbols('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/
/*Bit7 bit6 bit5 bit4 bit3 bit2 bit1 bit0*/
/* a    b    c     d    e   f    g    dp  共阴*/
const uint32_t FontTable[10] ={
/*0->1 1 1 1 1 1 0 0 */0xFC,
/*1->0 1 1 0 0 0 0 0 */0x60,
/*2->1 1 0 1 1 0 1 0 */0x14,	
/*3->1 1 1 1 0 0 1 0 */0xF2,	
/*4->0 1 1 0 0 1 1 0 */0x66,	
/*5->1 0 1 1 0 1 1 0 */0xB6,	
/*6->1 0 1 1 1 1 1 0 */0xBE,	
/*7->1 1 1 0 0 0 0 0 */0xE0,		
/*8->1 1 1 1 1 1 1 0 */0xFE,	
/*9->1 1 1 1 0 1 1 0 */0xF6,
};



/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
****************************************************************************/

/******************************************************************************
 ** \brief	 LED_Config
 ** \param [in] 
 **            	
 ** \return  none
 ** \note  
 ******************************************************************************/
void LED_Config(void)
{
	/*
	(1)设置LED模块运行模式
	*/
	LED_ConfigRunMode( LED_CLK_FSYS, LED_DUTY_4, LED_MODE_1,LED_COMSEL_1, LED_COM_CATHODE);

	/*设置扫描周期为 100HZ   
	 -> T = 4 * (COM有效时间 + 2*Tled)
	 -> T = 4 * ((ComValue +1) + 2)*Tled
	*/
	LED_ConfigClk(5999);				//Fsys=24Mhz，LED = 4Khz; ->250us
	LED_ConfigComTime(7);		    	//ComValue => 2ms
	
	/*
	(2)设置COM口
	*/
	GPIO_SET_MUX_MODE(P30CFG, GPIO_MUX_GPIO);	//COM0
	GPIO_SET_MUX_MODE(P31CFG, GPIO_MUX_GPIO);	//COM1	
	GPIO_SET_MUX_MODE(P32CFG, GPIO_MUX_GPIO);	//COM2
	GPIO_SET_MUX_MODE(P33CFG, GPIO_MUX_GPIO);	//COM3	
	
	P3TRIS = 0xF;		//开启输出
	LEDCOMEN = 0xF;		//使能COM0~COM3
		
	/*
	(3)设置SEG口
	*/	
	GPIO_SET_MUX_MODE(P10CFG, GPIO_MUX_GPIO);	//SEG0	->a
	GPIO_SET_MUX_MODE(P11CFG, GPIO_MUX_GPIO);	//SEG1	->b	
	GPIO_SET_MUX_MODE(P12CFG, GPIO_MUX_GPIO);	//SEG2	->c	
	GPIO_SET_MUX_MODE(P13CFG, GPIO_MUX_GPIO);	//SEG3	->d	
	GPIO_SET_MUX_MODE(P14CFG, GPIO_MUX_GPIO);	//SEG4	->e	
	GPIO_SET_MUX_MODE(P15CFG, GPIO_MUX_GPIO);	//SEG5	->f	
	GPIO_SET_MUX_MODE(P16CFG, GPIO_MUX_GPIO);	//SEG6	->g	
	GPIO_SET_MUX_MODE(P17CFG, GPIO_MUX_GPIO);	//SEG7	->dp	
	P1TRIS = 0xFF;
	

	LEDSEGEN0 = 0xFF;	//使能SEG0~SEG7	
	
	/*
	(4)设置SEG口电流
	*/		
	LEDSDRP1L = 0x04;		//10.9mA
	LEDSDRP1H = 0x04;		//10.9mA
	/*
	(5)设置COM口电流
	*/	
	P3DR = 0x0f;			// 150mA

	/*
	(6)设置SEG口数据
	*/
	LEDC0DATA0 = 0x00;
	LEDC1DATA0 = 0x00;	
	LEDC2DATA0 = 0x00;	
	LEDC3DATA0 = 0x00;

	/*
	(7)开启LED
	*/
	LED_Start();
}

/******************************************************************************
 ** \brief	 LED_Display
 ** \param [in] Comsel : 0~3
 **				SEGData : 段码
 ** \return  none
 ** \note  
 ******************************************************************************/
 void LED_Display(uint8_t Comsel, uint8_t SEGData)
 {
	switch(Comsel)
	{
		case 0:
			LEDC0DATA0 = SEGData;
		break;
		case 1:
			LEDC1DATA0 = SEGData;
		break;
		case 2:
			LEDC2DATA0 = SEGData;
		break;
		case 3:
			LEDC3DATA0 = SEGData;
		break;		
	}
 }


















