/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file mdu.c
**
**  
**
**	History:
**
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "mdu.h"

/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/
static  void delay_nop(void)
{
	_nop_();_nop_();_nop_();_nop_();_nop_();	/*5NOP */	
	_nop_();_nop_();_nop_();_nop_();_nop_();	/*5NOP */	
	_nop_();_nop_();_nop_();_nop_();_nop_();	/*5NOP */	
	_nop_();	/*1NOP */
}


/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
****************************************************************************/
/******************************************************************************
 ** \brief MDU_LDiv
 **		   32λ16λ
 ** \param [in] DividendAddr 32λַ
 **				DivsiorAddr  16λַ
 **				QuotientAddr 32λ̵ַ	
 **				RemainderAddr:  16Ϊַ
 ** \return 0: 쳣
 **			1
******************************************************************************/
uint8_t  MDU_LDiv(uint32_t * DividendAddr, uint16_t *DivsiorAddr, uint32_t *QuotientAddr, uint16_t * RemainderAddr)
{
	SFRS = 0x1;		/*ѡBANK1*/	
	MD0 = (*DividendAddr) & 0xFF;
	MD1 = ((*DividendAddr)>>8) &0xFF;	
	MD2 = ((*DividendAddr)>>16) &0xFF;		
	MD3 = ((*DividendAddr)>>24) &0xFF;		
	MD4 = (*DivsiorAddr) &0xFF;		
	MD5 = ((*DivsiorAddr)>>8) &0xFF;		
	delay_nop();	
	if(ARCON &  MDU_ARCON_MDOV_Msk)
	{
		SFRS = 0x0;		/*ѡBANK0*/	
		return 0;
	}
		
	*QuotientAddr = ((uint32_t)MD0) | (((uint32_t)MD1)<<8) | (((uint32_t)MD2)<<16) | (((uint32_t)MD3)<<24);	
	*RemainderAddr = MD4 | (MD5<<8);		
	SFRS = 0x0;		/*ѡBANK0*/	
	return 1;
}

/******************************************************************************
 ** \brief MDU_Div
 **		   16λ16λ
 ** \param [in] DividendAddr 16λַ
 **				DivsiorAddr  16λַ
 **				QuotientAddr 16λ̵ַ	
 **				RemainderAddr:  16Ϊַ
 ** \return 0: 쳣
 **			1
******************************************************************************/
uint8_t  MDU_Div(uint16_t * DividendAddr, uint16_t *DivsiorAddr, uint16_t *QuotientAddr, uint16_t * RemainderAddr)
{
	SFRS = 0x1;		/*ѡBANK1*/	
	MD0 = (*DividendAddr) & 0xFF;
	MD1 = ((*DividendAddr)>>8) &0xFF;		
	MD4 = (*DivsiorAddr) &0xFF;		
	MD5 = ((*DivsiorAddr)>>8) &0xFF;		
	delay_nop();	
	if(ARCON &  MDU_ARCON_MDOV_Msk)
	{
		SFRS = 0x0;		/*ѡBANK0*/	
		return 0;
	}	
	*QuotientAddr = MD0 |(MD1<<8);	
	*RemainderAddr = MD4 | (MD5<<8);		
	SFRS = 0x0;		/*ѡBANK0*/	
	return 1;
}

/******************************************************************************
 ** \brief MDU_Mul
 **		   16λ16λ˷
 ** \param [in] Param0Addr 16λַ
 **				Param1Addr  16λַ
 **				Result 32λַ	
 ** \return 0: ˷쳣
 **			1˷
******************************************************************************/
void MDU_Mul(uint16_t * Param0Addr, uint16_t *Param1Addr, uint32_t *Result)
{
	SFRS = 0x1;		/*ѡBANK1*/	
	MD0 = (*Param0Addr) & 0xFF;
	MD4 = (*Param1Addr) &0xFF;		
	MD1 = ((*Param0Addr)>>8) &0xFF;			
	MD5 = ((*Param1Addr)>>8) &0xFF;		
	delay_nop();	
	
	*Result = ((uint32_t)MD0) | (((uint32_t)MD1)<<8) | (((uint32_t)MD2)<<16) | (((uint32_t)MD3)<<24);		
	SFRS = 0x0;		/*ѡBANK0*/	
}

/******************************************************************************
 ** \brief MDU_LeftShift
 **		  32λ߼
 ** \param [in] ParamAddr ݵַ
**				ShiftVlaue: λλ (1~31)
 ** \return 0: λ쳣
 **			1λ
******************************************************************************/
uint8_t  MDU_LeftShift(uint32_t * ParamAddr, uint8_t ShiftVlaue)
{
	if((ShiftVlaue == 0) || (ShiftVlaue > 31))
		return 0;
	SFRS = 0x1;		/*ѡBANK1*/	
	MD0 = (*ParamAddr) & 0xFF;
	MD1 = ((*ParamAddr)>>8) &0xFF;	
	MD2 = ((*ParamAddr)>>16) &0xFF;		
	MD3 = ((*ParamAddr)>>24) &0xFF;	
	ARCON = (0x1f & ShiftVlaue);
	delay_nop();	
	
	*ParamAddr = ((uint32_t)MD0) | (((uint32_t)MD1)<<8) | (((uint32_t)MD2)<<16) | (((uint32_t)MD3)<<24);		
	SFRS = 0x0;		/*ѡBANK0*/	
	return 1;	
}
/******************************************************************************
 ** \brief MDU_RightShift
 **		  32λ߼
 ** \param [in] ParamAddr ݵַ
**				ShiftVlaue: λλ (1~31)
 ** \return 0: λ쳣
 **			1λ
******************************************************************************/
uint8_t  MDU_RightShift(uint32_t * ParamAddr, uint8_t ShiftVlaue)
{
	if((ShiftVlaue == 0) || (ShiftVlaue > 31))
		return 0;
	SFRS = 0x1;		/*ѡBANK1*/	
	MD0 = (*ParamAddr) & 0xFF;
	MD1 = ((*ParamAddr)>>8) &0xFF;	
	MD2 = ((*ParamAddr)>>16) &0xFF;		
	MD3 = ((*ParamAddr)>>24) &0xFF;	
	ARCON = MDU_ARCON_SLR_Msk | (0x1f & ShiftVlaue);
	delay_nop();	

	*ParamAddr = ((uint32_t)MD0) | (((uint32_t)MD1)<<8) | (((uint32_t)MD2)<<16) | (((uint32_t)MD3)<<24);		
	SFRS = 0x0;		/*ѡBANK0*/	
	return 1;	
}
